SmartThumbTheme class

Constructors

SmartThumbTheme(Color thumbnailColor, Color backgroundColor, bool hasBorder)
const
SmartThumbTheme.enabled(BuildContext context)
factory
SmartThumbTheme.selected(BuildContext context)
factory

Properties

backgroundColor Color
final
hasBorder bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited