ActivableListItemData class
- Inheritance
-
- Object
- BaseListItemData
- ActivableListItemData
Constructors
- ActivableListItemData({required String primaryText, required String id, String? labelText, BaseListItemLeading? leading, String? secondaryText, SmartTag? tag, bool disabled = false})
Properties
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- labelText → String?
-
finalinherited
- leading → BaseListItemLeading?
-
finalinherited
- primaryText → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryText → String?
-
finalinherited
- tag → SmartTag?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited