SmartThumbnailImageSize enum
Values
- xxss → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s16) - xxs → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s24) - xs → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s32) - s → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s40) - m → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s48) - l → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s56) - xl → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s64) - xxl → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s72) - xxxl → const SmartThumbnailImageSize
-
const SmartThumbnailImageSize(SmartSpace.s80)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SmartThumbnailImageSize> - A constant List of the values in this enum, in order of their declaration.